==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/GridColumnsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnsChangedEventArgsDescription } from "./GridColumnsChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridColumnsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnsChangedEventArgsDescriptionMetadata.a == null) {
                GridColumnsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnsChangedEventArgsDescriptionMetadata.c(GridColumnsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridColumnsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridColumnsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Columns", "Collection:DataGridColumn:GridColumnCollection:DataGridColumn");
        }
        static d(a) {
            GridColumnsChangedEventArgsDescriptionMetadata.b(a);
            a.ad("GridColumnsChangedEventArgs", () => new GridColumnsChangedEventArgsDescription());
            a.ac("GridColumnsChangedEventArgs", GridColumnsChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridColumnsChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnsChangedEventArgsDescriptionMetadata, 'GridColumnsChangedEventArgsDescriptionMetadata');
    GridColumnsChangedEventArgsDescriptionMetadata.a = null;
    return GridColumnsChangedEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/GridColumnsChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnsChangedEventArgsDescription } from "./GridColumnsChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridColumnsChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnsChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnsChangedEventArgsDescriptionMetadata.a == null) {
                GridColumnsChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnsChangedEventArgsDescriptionMetadata.c(GridColumnsChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridColumnsChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridColumnsChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Columns", "Collection:DataGridColumn:GridColumnCollection:DataGridColumn");
        }
        static d(a) {
            GridColumnsChangedEventArgsDescriptionMetadata.b(a);
            a.ae("GridColumnsChangedEventArgs", () => new GridColumnsChangedEventArgsDescription());
            a.ad("GridColumnsChangedEventArgs", GridColumnsChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridColumnsChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnsChangedEventArgsDescriptionMetadata, 'GridColumnsChangedEventArgsDescriptionMetadata');
    GridColumnsChangedEventArgsDescriptionMetadata.a = null;
    return GridColumnsChangedEventArgsDescriptionMetadata;
})();
